summaryrefslogtreecommitdiffstats
path: root/kate/part/katetextline.h
diff options
context:
space:
mode:
Diffstat (limited to 'kate/part/katetextline.h')
-rw-r--r--kate/part/katetextline.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kate/part/katetextline.h b/kate/part/katetextline.h
index a954c87ea..3922d04d0 100644
--- a/kate/part/katetextline.h
+++ b/kate/part/katetextline.h
@@ -32,10 +32,10 @@ class KateRenderer;
class TQTextStream;
/**
- * The KateTextLine represents a line of text. A text line that tqcontains the
+ * The KateTextLine represents a line of text. A text line that contains the
* text, an attribute for each character, an attribute for the free space
* behind the last character and a context number for the syntax highlight.
- * The attribute stores the index to a table that tqcontains fonts and colors
+ * The attribute stores the index to a table that contains fonts and colors
* and also if a character is selected.
*/
class KateTextLine : public KShared
@@ -145,16 +145,16 @@ class KateTextLine : public KShared
inline TQChar getChar (uint pos) const { return m_text[pos]; }
/**
* Gets the text as a tqunicode representation
* @return text of this line as TQChar array
*/
- inline const TQChar *text() const { return m_text.tqunicode(); }
+ inline const TQChar *text() const { return m_text.unicode(); }
/**
* Highlighting array
* The size of this is string().length()
*
- * This tqcontains the index for the attributes (so you can only
+ * This contains the index for the attributes (so you can only
* have a maximum of 2^8 different highlighting styles in a document)
*
* To turn this into actual attributes (bold, green, etc),
@@ -211,7 +211,7 @@ class KateTextLine : public KShared
uint lengthWithTabs (uint tabChars) const;
/**
- * Can we tqfind the given string at the given position
+ * Can we find the given string at the given position
* @param pos startpostion of given string
* @param match string to match at given pos
* @return did the string match?
@@ -419,7 +419,7 @@ class KateTextLine : public KShared
*/
private:
/**
* text of line as tqunicode
*/
TQString m_text;
@@ -453,4 +453,4 @@ class KateTextLine : public KShared
#endif
-// kate: space-indent on; indent-width 2; tqreplace-tabs on;
+// kate: space-indent on; indent-width 2; replace-tabs on;
@@ -145,16 +145,16 @@ class KateTextLine : public KShared
inline TQChar getChar (uint pos) const { return m_text[pos]; }
/**
- * Gets the text as a tqunicode representation
+ * Gets the text as a unicode representation
* @return text of this line as TQChar array
*/
@@ -419,7 +419,7 @@ class KateTextLine : public KShared
private:
/**
- * text of line as tqunicode
+ * text of line as unicode
*/
TQString m_text;